% Pegel Innsbruck, Inn 1971 - 1980
 
% Extremwerte der Abflsse 1971 - 1980

HQ = [550 490 590 660 1030 445 713 797 702 778]; % 2005: 1540

% Anpassung der zweiparametrigen Gumbelverteilung (Plate, p. 154):

muy = mean(HQ)  % muy = 675.5000

sigmay = std(HQ) % sigmay = 171.2336

lambda = pi/(sigmay*sqrt(6)) % lambda = 0.0075

y0 = muy - 0.577216/lambda % y0 = 598.4357

y = 200:1800;
% Dichte der Gumbelverteilung
fy = exp(-lambda*(y-y0)).*exp(-exp(-lambda*(y-y0)))*lambda;


% Darstellung als Histogramm
figure
hold on
Z = 400:100:1700; % Mittelpunkte der Bins, Binbreite = 100
N1 = hist(HQ,Z); 

Y1 = N1/1000; % N1 dividiert durch Gesamtzahl n = 10 mal Binbreite 1000
bar(Z,Y1,1)
h = findobj(gca,'Type','patch');
set(h,'FaceColor','w','Edgecolor','k','LineWidth',1.5); % Histogramm schwarz-wei
plot([200 1700],[0 0],'k-','LineWidth',1.5)

plot(y,fy,'r-','LineWidth',2)

axis([200 1700 0 0.0032])
set(GCA, 'FontSize',12)
set(gca,'YTick',[0.0005 0.001 0.0015 0.002 0.0025 0.003])
set(gca,'YTicklabel',{'0.0005'; '0.001'; '0.0015'; '0.002'; '0.0025'; '0.003'})
legend('rel. Hufigkeit', 'Gumbelverteilung')
title('Inn 1971 - 1980: Jahresmaxima - HQ [m^3/s]')
box off
hold off


% Plot fr kumulative Gumbelverteilung
figure
plot(y,cumsum(fy),'r-','LineWidth',1.5)
axis([200 1700 -0.05 1.05])
grid
set(GCA, 'FontSize',12)
title('Inn: Jahresmaxima, berschreitenswahrscheinlichkeit')
box off


% Vergleich mit den Daten fr HQ:

HQgeord = [300 445 445 490 550 590 660 702 713 778 797 1030 1700];
spHQ = [0 0 0.1 0.2 0.3 0.4 0.5 0.6 0.7 0.8 0.9 1 1];

figure
hold on
plot(HQgeord,spHQ,'b','Linewidth',1.5)
plot(y,cumsum(fy),'r','Linewidth',1.5)
axis([200 1700 -0.05 1.05])
grid
set(GCA, 'FontSize',12)
legend('Daten','Anpassung',0)
title('Inn 1971 - 1980, Jahresmaxima und Gumbelverteilung kumulativ')
hold off


% Wahrscheinlichkeit von 1525
W1525 = exp(-exp(-lambda*(1525-y0))) 
% Jhrlichkeit
J1525 = round(1/(1-W1525))    %  1033 (berechnet)

% Wahrscheinlichkeit von 1540
W1540 = exp(-exp(-lambda*(1540-y0))) 
% Jhrlichkeit
J1540 = round(1/(1-W1540))    %  1156 (berechnet)

% Berechnung der Jhrlichkeiten

x = 400:0.01:2000;
% Wahrscheinlichkeit von x
W = exp(-exp(-lambda*(x-y0))); 
% Jhrlichkeit
J = (1./(1-W));

%Quantile mit p = W von oben
Qp = y0 - log(-log(W))/lambda;
Kp = (Qp - muy)/sigmay;
sigmaQp = sigmay*sqrt((1 + 1.1396*Kp + 1.1*Kp.^2)/10); % n = 10

Q80 = y0 - log(-log(0.8))/lambda    % 798.7 (berechnet)
Q90 = y0 - log(-log(0.9))/lambda    % 898.9
Q95 = y0 - log(-log(0.95))/lambda   % 995.0
Q99 = y0 - log(-log(0.99))/lambda   % 1212.6


% Empirische Daten
HQemp = [445 490 550 590 660 702 713 778 797 1030];
WQemp = [0.1 0.2 0.3 0.4 0.5 0.6 0.7 0.8 0.9 1]-0.05; % empirische Summenfunktion gemittelt
JQemp = 1./(1-WQemp);

figure
semilogx(J,x,'k','linewidth',1.5)
hold on
%semilogx(J,x-1.96*sigmaQp)
%semilogx(J,x+1.96*sigmaQp)
semilogx(JQemp,HQemp,'o','markerfacecolor','b','markeredgecolor','b','markersize',4)
axis([1 1000 400 1900])
set(GCA, 'FontSize',12)
set(gca,'xTick',[1 10 100 1000])
set(gca,'xTicklabel',{'1'; '10'; '100'; '1000';})
legend('Prognose', 'Daten')
title('Inn 1971 - 1980: Prognose mittels Gumbelverteilung')
box off
grid
hold off

figure
semilogx(J,x,'k','linewidth',1.5)
hold on
semilogx(J,x+1.96*sigmaQp,'r','linewidth',1.5)
semilogx(J,x-1.96*sigmaQp,'b','linewidth',1.5)
axis([1 1000 400 1900])
set(GCA, 'FontSize',12)
set(gca,'xTick',[1 10 100 1000])
set(gca,'xTicklabel',{'1'; '10'; '100'; '1000';})
legend('Prognose', '95% KI oben', '95% KI unten')
title('Inn 1971 - 1980: Prognose und Konfidenzintervalle')
box off
grid
hold off


% Zusammenfassendes Bild

figure
semilogx(J,x,'k','linewidth',1.8)
hold on
semilogx(J,x+1.96*sigmaQp,'r','linewidth',1.8)
semilogx(J,x-1.96*sigmaQp,'b','linewidth',1.8)
semilogx(JQemp,HQemp,'o','markerfacecolor','k','markeredgecolor','k','markersize',4)
axis([1 1000 400 1900])
set(GCA, 'FontSize',14)
set(gca,'xTick',[1 10 100 1000])
set(gca,'xTicklabel',{'1'; '10'; '100'; '1000';})
legend('Prognose', '95% KI oben', '95% KI unten','Daten')
title('Hochwasserprognose: Jhrlichkeit vs. Abfluss HQ')
box off
grid
hold off